pywws.ZambrettiCore — pywws 12.12_e27456b documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 12.12_e27456b documentation »
- Python programs and modules »

# pywws.ZambrettiCore

Functions

`Zambretti` |

`pywws.ZambrettiCore.` `ZambrettiCode`(pressure, month, wind, trend, north=True, baro_top=1050.0, baro_bottom=950.0)

  Simple implementation of Zambretti forecaster algorithm. Inspired by beteljuice.com Java algorithm, as converted to Python by honeysucklecottage.me.uk, and further information from http://www.meteormetrics.com/zambretti.htm

`pywws.ZambrettiCore.` `ZambrettiText`(letter)

`pywws.ZambrettiCore.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 12.12_e27456b documentation »
- Python programs and modules »